Baselines

Struct Baselines 

pub struct Baselines {
    pub first: Option<f32>,
    pub last: Option<f32>,
}
The first and last baselines of a node in the horizontal axis (i.e. baselines for horizontal text, measured as an offset from the top edge of the node’s border box).

A baseline is the line on which text sits. See https://www.w3.org/TR/css-writing-modes-3/#intro-baselines for details.

Fields

first: Option<f32>

The first baseline of the node, if any

last: Option<f32>

The last baseline of the node, if any

Implementations

Source

impl Baselines

pub const NONE: Self

A Baselines with neither a first nor a last baseline

pub const fn from_first(first: Option<f32>) -> Self

Create a Baselines from just a first baseline