pub struct LayoutOutput {
pub size: Size<f32>,
pub baselines: Baselines,
pub top_margin: CollapsibleMarginSet,
pub bottom_margin: CollapsibleMarginSet,
pub margins_can_collapse_through: bool,
}Expand description
A struct containing the result of laying a single node, which is returned up to the parent node
A baseline is the line on which text sits. Your node likely has a baseline if it is a text node, or contains
children that may be text nodes. See https://www.w3.org/TR/css-writing-modes-3/#intro-baselines for details.
If your node does not have a baseline (or you are unsure how to compute it), then simply return Baselines::NONE
for the baselines field
Fields
size: Size<f32>The size of the node
baselines: BaselinesThe first and last baselines of the node in the horizontal axis, if any
top_margin: CollapsibleMarginSetTop margin that can be collapsed with. This is used for CSS block layout and can be set to
CollapsibleMarginSet::ZERO for other layout modes that don’t support margin collapsing
bottom_margin: CollapsibleMarginSetBottom margin that can be collapsed with. This is used for CSS block layout and can be set to
CollapsibleMarginSet::ZERO for other layout modes that don’t support margin collapsing
margins_can_collapse_through: boolWhether margins can be collapsed through this node. This is used for CSS block layout and can
be set to false for other layout modes that don’t support margin collapsing
Implementations
Sourceimpl LayoutOutput
impl LayoutOutput
Sourcepub fn from_sizes_and_baselines(
size: Size<f32>,
scrollable_overflow_rect: Rect<f32>,
baselines: Baselines,
) -> Self
pub fn from_sizes_and_baselines( size: Size<f32>, scrollable_overflow_rect: Rect<f32>, baselines: Baselines, ) -> Self
Constructor to create a LayoutOutput from just the size, scrollable overflow rectangle and baselines
Sourcepub fn from_sizes(size: Size<f32>, scrollable_overflow_rect: Rect<f32>) -> Self
pub fn from_sizes(size: Size<f32>, scrollable_overflow_rect: Rect<f32>) -> Self
Construct a LayoutOutput from just the container size and scrollable overflow rectangle
Sourcepub fn from_outer_size(size: Size<f32>) -> Self
pub fn from_outer_size(size: Size<f32>) -> Self
Construct a LayoutOutput from just the container’s size.